searchData={"items":[{"type":"module","title":"TwScreenSize","doc":"Documentation for `TwScreenSize`. A tiny LiveView widget showing the current screen dimensions and Tailwind breakpoint.","ref":"TwScreenSize.html"},{"type":"function","title":"TwScreenSize.tw_screen_size/1","doc":"","ref":"TwScreenSize.html#tw_screen_size/1"},{"type":"function","title":"Attributes - TwScreenSize.tw_screen_size/1","doc":"* `base_class` (`:string`) - Override the default styling with a custom class. This is appended to the always required classes: `hidden fixed opacity-0 transition-opacity z-[999]`. Defaults to `\"items-center space-x-2 rounded-full bg-black px-2.5 py-1 font-mono text-xs font-medium text-white\"`.\n* `placement_class` (`:string`) - Classes to determine where the screen size component is placed on the screen. Defaults to `bottom-5 left-5`. Defaults to `\"bottom-5 left-5\"`.\n* `transition_duration_class` (`:string`) - The Tailwind transition duration class. Defaults to `duration-300`. Defaults to `\"duration-300\"`.\n* `opacity_timeout` (`:integer`) - Make the component 100% transparent after this timeout in milliseconds. Becomes visible on initial page load and during resizes. Disabled by default.","ref":"TwScreenSize.html#tw_screen_size/1-attributes"},{"type":"extras","title":"TwScreenSize","doc":"# TwScreenSize\n\n![tw_screen_size_gif](https://pub-0bd602de4141434f899c6f284446e48a.r2.dev/twScreenSize.gif)\n\nA tiny LiveView widget showing the current screen dimensions and Tailwind breakpoint. Ported from [Shayan Taslim](https://github.com/Sh4yy)'s React implementation (see [Gist](https://gist.github.com/Sh4yy/0300299ae60af4910bcb341703946330)).","ref":"readme.html"},{"type":"extras","title":"Installation - TwScreenSize","doc":"Prerequisites: Your LiveView application must already be using TailwindCSS.\n\n1. Install the package from Hex by adding `tw_screen_size` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tw_screen_size, \"~> 1.0.0\"}\n  ]\nend\n```\n\n2. Ensure Tailwind searches for styles in the `tw_screen_size` package:\n\n```js\n// assets/tailwind.config.js\nmodule.exports = {\n  content: [\n    \"../deps/tw_screen_size/**/*.{ex,js}\", // <--- Add this line\n  ],\n  ...\n}\n```\n\n3. Import and integrate the `TwScreenSizeHook` in your `app.js`:\n\n```js\n// assets/app.js\n\n// import the hook\nimport { TwScreenSizeHook } from \"../../deps/tw_screen_size/assets/js/hooks\";\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: { ...OtherHooks, TwScreenSizeHook }, // <--- Add TwScreenSizeHook here\n  params: { _csrf_token: csrfToken },\n});\n```\n\n4. Extend your `dev.exs` configuration to enable the component in development only:\n\n```elixir\n# dev.exs\nconfig :my_app, tw_screen_size: true\n```\n\n5. Import TwScreenSize, and add the component to your root layout:\n\n```elixir\n# layouts.ex\ndefmodule MyAppWeb.Layouts do\n  use MyAppWeb, :html\n  import TwScreenSize\n\n  embed_templates \"layouts/*\"\nend\n```\n\n```heex\n<!-- root.html.heex -->\n<!-- ... -->\n \n  <%= @inner_content %>\n  <.tw_screen_size :if={Application.get_env(:my_app, :tw_screen_size)} />\n \n```","ref":"readme.html#installation"},{"type":"extras","title":"Opacity Timeout - TwScreenSize","doc":"The component is always visible by default. If you'd prefer it to appear temporarily on the first page-load, and on screen resizes, you can set the `:opacity_timeout` attribute:\n\n```elixir\n<.tw_screen_size\n  :if={Application.get_env(:my_app, :tw_screen_size)}\n  opacity_timeout={3000}\n/>\n```","ref":"readme.html#opacity-timeout"},{"type":"extras","title":"All Attributes - TwScreenSize","doc":"```elixir\nattr :base_class, :string,\n  default:\n    \"items-center space-x-2 rounded-full bg-black px-2.5 py-1 font-mono text-xs font-medium text-white\",\n  doc:\n    \"Override the default styling with a custom class. This is appended to the always required classes: `hidden fixed opacity-0 transition-opacity z-[999]`.\"\n\nattr :placement_class, :string,\n  default: \"bottom-5 left-5\",\n  doc:\n    \"Classes to determine where the screen size component is placed on the screen. Defaults to `bottom-5 left-5`.\"\n\nattr :transition_duration_class, :string,\n  default: \"duration-300\",\n  doc: \"The Tailwind transition duration class. Defaults to `duration-300`.\"\n\nattr :opacity_timeout, :integer,\n  doc:\n    \"Make the component 100% transparent after this timeout in milliseconds. Becomes visible on initial page load and during resizes. Disabled by default.\"\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#all-attributes"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.0.0 - Changelog","doc":"- Add index.d.ts type definitions","ref":"changelog.html#1-0-0"},{"type":"extras","title":"0.1.0 - Changelog","doc":"- Initial release","ref":"changelog.html#0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}